@@ -2,8 +2,8 @@
 #
 # read.cross.csvs.R
 #
-# copyright (c) 2005-2015, Karl W Broman
-# last modified Aug, 2015
+# copyright (c) 2005-2020, Karl W Broman
+# last modified Feb, 2020
 # first written Oct, 2005
 #
 #     This program is free software; you can redistribute it and/or
@@ -66,17 +66,21 @@ read.cross.csvs <-
         if(length(args) < 1 || !("comment.char" %in% names(args))) {
             gen <- read.table(genfile, sep=",", na.strings=na.strings,
                               colClasses="character", fill=TRUE,
+                              stringsAsFactors=TRUE,
                               blank.lines.skip=TRUE, comment.char="", ...)
             pheno <- read.table(phefile, sep=",", na.strings=na.strings,
                                 colClasses="character", fill=TRUE,
+                                stringsAsFactors=TRUE,
                                 blank.lines.skip=TRUE, comment.char="", ...)
         }
         else {
             gen <- read.table(genfile, sep=",", na.strings=na.strings,
                               colClasses="character", fill=TRUE,
+                              stringsAsFactors=TRUE,
                               blank.lines.skip=TRUE, ...)
             pheno <- read.table(phefile, sep=",", na.strings=na.strings,
                                 colClasses="character", fill=TRUE,
+                                stringsAsFactors=TRUE,
                                 blank.lines.skip=TRUE, ...)
         }
     }
@@ -84,17 +88,21 @@ read.cross.csvs <-
         if(length(args) < 1 || !("comment.char" %in% names(args))) {
             gen <- read.table(genfile, na.strings=na.strings,
                               colClasses="character", fill=TRUE,
+                              stringsAsFactors=TRUE,
                               blank.lines.skip=TRUE, comment.char="", ...)
             pheno <- read.table(phefile, na.strings=na.strings,
                                 colClasses="character", fill=TRUE,
+                                stringsAsFactors=TRUE,
                                 blank.lines.skip=TRUE, comment.char="", ...)
         }
         else {
             gen <- read.table(genfile, na.strings=na.strings,
                               colClasses="character", fill=TRUE,
+                              stringsAsFactors=TRUE,
                               blank.lines.skip=TRUE, ...)
             pheno <- read.table(phefile, na.strings=na.strings,
                                 colClasses="character", fill=TRUE,
+                                stringsAsFactors=TRUE,
                                 blank.lines.skip=TRUE, ...)
         }
     }
@@ -327,9 +335,8 @@ read.cross.csvs <-
     class(cross) <- c(type,"cross")
 
     # check that nothing is strange in the genotype data
-    cross.type <- class(cross)[1]
-    if(cross.type=="f2") max.gen <- 5
-    else if(cross.type=="bc") max.gen <- 2
+    if(type=="f2") max.gen <- 5
+    else if(type=="bc") max.gen <- 2
     else max.gen <- 14
 
     # check that markers are in proper order
@@ -342,12 +349,6 @@ read.cross.csvs <-
         }
     }
 
-    # if 4-way cross, make the maps matrices
-    if(type=="4way") {
-        for(i in 1:n.chr)
-            cross$geno[[i]]$map <- rbind(cross$geno[[i]]$map, cross$geno[[i]]$map)
-    }
-
     # estimate genetic map
     if(estimate.map && !map.included) estmap <- TRUE
     else estmap <- FALSE
